# Create your views here.
from rest_framework import serializers  # type:ignore
from rest_framework import viewsets, mixins
from .models import Order, OrderItem
from modules.inventory.models import Product
from modules.inventory.views import ProductSerializer


class ItemSerializer(serializers.ModelSerializer):
    quantity = serializers.IntegerField(required=False)
    unit_price = serializers.FloatField(required=False)
    description = serializers.CharField(required=False)

    class Meta:
        model = OrderItem
        fields = ["description", "quantity", "unit_price", "total"]


class OrderSerializer(serializers.ModelSerializer):
    items = ItemSerializer(many=True)

    def create(self, validated_data):
        order = Order.objects.create()
        # I want to be able to access the id, the id represent the Product id
        # So, I'm using initial_data instead of validated_data
        # I'll need to find a proper way
        for item_data in self.initial_data["items"]:
            product = Product.objects.get(id=item_data["id"])
            OrderItem.objects.create(
                id=product.id,
                order=order,
                description=product.description,
                unit_price=product.unit_price,
                quantity=item_data["quantity"],
            )
        return order

    class Meta:
        model = Order
        fields = ["id", "items", "total"]


# https://git.disroot.org/nsukami/interview/src/branch/feat-1/src/modules/orders/tests.py#L189
# an order can be listed, created, updated but not deleted
class OrdersViewSet(
    mixins.CreateModelMixin,
    mixins.ListModelMixin,
    mixins.RetrieveModelMixin,
    viewsets.GenericViewSet,
):

    queryset = Order.objects.all()
    serializer_class = OrderSerializer
